@@ -1,4 +1,5 @@
-#pragma once
+#ifndef LIBRAPID_CONFIG_HPP
+#define LIBRAPID_CONFIG_HPP
 
 // Include required headers
 #include <cstdlib>
@@ -14,9 +15,15 @@
 #include <iostream>
 #include <atomic>
 #include <thread>
+#include <future>
 #include <random>
 #include <fstream>
 #include <streambuf>
+#include <utility>
+
+#if defined(__unix__)
+#	include <unistd.h>
+#endif
 
 #if defined(_OPENMP)
 #	include <omp.h>
@@ -45,9 +52,11 @@
 #include <scn/tuple_return/tuple_return.h>
 
 // SIMD instructions
-#include <Vc/Vc>
-#include <Vc/algorithm>
-#include <Vc/cpuid.h>
+#if defined(LIBRAPID_USE_VC)
+#	include <Vc/Vc>
+#	include <Vc/algorithm>
+#	include <Vc/cpuid.h>
+#endif
 
 // LibRapid definitions
 
@@ -240,17 +249,34 @@
 #	endif
 #endif
 
+// If we don't know, defualt to 64 bit
+#if !defined(LIBRAPID_32BIT) && !defined(LIBRAPID_64BIT)
+#	define LIBRAPID_64BIT
+#endif
+
 // Check C++ Version
-#if __cplusplus >= 201103L
-#	define LIBRAPID_CXX_11
-#elif __cplusplus >= 201402L
-#	define LIBRAPID_CXX_14
-#elif __cplusplus >= 201703L
-#	define LIBRAPID_CXX_17
-#elif __cplusplus >= 202002L
-#	define LIBRAPID_CXX_20
+#if defined(LIBRAPID_MSVC_CXX)
+// https://developercommunity.visualstudio.com/t/msvc-incorrectly-defines-cplusplus/139261
+// MSVC incorrectly defines the C++ version, so we cannot reliably detect it.
+#	if defined(_HAS_CXX20) && _HAS_CXX20
+#		define LIBRAPID_CXX_20
+#	else
+#		define LIBRAPID_CXX_17
+#	endif
 #else
-#	define LIBRAPID_CXX_11 // Assume we're using C++ 11???
+#	if __cplusplus >= 199711L
+#		define LIBRAPID_CXX_98
+#	elif __cplusplus >= 201103L
+#		define LIBRAPID_CXX_11
+#	elif __cplusplus >= 201402L
+#		define LIBRAPID_CXX_14
+#	elif __cplusplus >= 201703L
+#		define LIBRAPID_CXX_17
+#	elif __cplusplus >= 202002L
+#		define LIBRAPID_CXX_20
+#	else
+#		define LIBRAPID_CXX_11 // Assume we're using C++ 11???
+#	endif
 #endif
 
 // Nice-to-have macros
@@ -318,6 +344,9 @@
 #	endif
 #endif
 
+#define STRINGIFY(a) STR_IMPL_(a)
+#define STR_IMPL_(a) #a
+
 // Settings and macros for inline functions
 #if defined(LIBRAPID_NO_INLINE)
 #	define LR_INLINE
@@ -932,15 +961,18 @@ namespace librapid {
 	static inline std::vector<std::string> nvccOptions	 = {};
 	static inline std::vector<std::string> customHeaders = {};
 	static inline std::string customCudaCode;
+	static inline bool checkComplex = true; // Use faster, less safe methods in the Complex type
+
+	void prec(int64_t dig10);
 
 	namespace internal {
 		class PreOptimize {
 		public:
 			PreOptimize() {
-				numThreads	  = std::thread::hardware_concurrency() * (3. / 4.);
+				numThreads	  = (int64_t)((double)std::thread::hardware_concurrency() * (3. / 4.));
 				matrixThreads = std::thread::hardware_concurrency();
-
 				nvccOptions.emplace_back("--device-int128");
+				prec(25);
 			}
 		};
 
@@ -948,8 +980,6 @@ namespace librapid {
 	} // namespace internal
 } // namespace librapid
 
-#include "../math/mpir.hpp"
-
 // Prefer using the GPU over the CPU -- promote arrays to the GPU where possible
 #if !defined(LIBRAPID_PREFER_CPU)
 #	define LIBRAPID_PREFER_GPU
@@ -962,3 +992,6 @@ namespace librapid {
 	template<class T, class U>
 	constexpr bool is_same_v = std::is_same<T, U>::value;
 } // namespace librapid
+
+#include "../math/mpfr.hpp"
+#endif // LIBRAPID_CONFIG_HPP
\ No newline at end of file
