@@ -1,23 +1,17 @@
 #ifndef LIBRAPID_VECTOR
 #define LIBRAPID_VECTOR
 
-#include <cstdint>
-#include <cstring>
-#include <librapid/config.hpp>
-#include <ostream>
-#include <type_traits>
+#include "../internal/config.hpp"
 
 namespace librapid {
 #ifndef LIBRAPID_DOXYGEN_BUILD
-#	define MIN_DIM_CLAMP(_dims, _tmpDims)                                     \
-		(((_dims) < (_tmpDims)) ? (_dims) : (_tmpDims))
+#	define MIN_DIM_CLAMP(_dims, _tmpDims) (((_dims) < (_tmpDims)) ? (_dims) : (_tmpDims))
 #else
 #	define MIN_DIM_CLAMP(_dims, _tmpDims) _dims
 #endif
 
 #ifndef LIBRAPID_DOXYGEN_BUILD
-#	define MAX_DIM_CLAMP(_dims, _tmpDims)                                     \
-		(((_dims) > (_tmpDims)) ? (_dims) : (_tmpDims))
+#	define MAX_DIM_CLAMP(_dims, _tmpDims) (((_dims) > (_tmpDims)) ? (_dims) : (_tmpDims))
 #else
 #	define MAX_DIM_CLAMP(_dims, _tmpDims) _dims
 #endif
@@ -27,21 +21,25 @@ namespace librapid {
 		template<typename T>
 		using Common = typename std::common_type<DTYPE, T>::type;
 
-	  public:
+	public:
 		Vec() = default;
 
 		template<typename X, typename... YZ>
-		Vec(X x, YZ... yz) : m_components {(DTYPE)x, (DTYPE)yz...} {
-			static_assert(1 + sizeof...(YZ) <= dims,
-						  "Parameters cannot exceed vector dimensions");
+		explicit Vec(X x, YZ... yz) : m_components {(DTYPE)x, (DTYPE)yz...} {
+			static_assert(sizeof...(YZ) <= dims, "Parameters cannot exceed vector dimensions");
+		}
+
+		template<typename T>
+		Vec(const std::initializer_list<T> &vals) {
+			LR_ASSERT(vals.size() <= dims, "Parameters cannot exceed vector dimensions");
+			int64_t ind = 0;
+			for (const auto &val : vals) { m_components[ind++] = val; }
 		}
 
 		template<typename T, int64_t d>
-		Vec(const Vec<T, d> &other) {
+		explicit Vec(const Vec<T, d> &other) {
 			int64_t i;
-			for (i = 0; i < dims < d ? dims : d; ++i) {
-				m_components[i] = other[i];
-			}
+			for (i = 0; i < MIN_DIM_CLAMP(dims, d); ++i) { m_components[i] = other[i]; }
 		}
 
 		template<typename T>
@@ -72,7 +70,7 @@ namespace librapid {
 			}
 		}
 
-		template<typename T, int tmpDim, glm::qualifier p = glm::defaultp>
+		template<typename T = DTYPE, int tmpDim = dims, glm::qualifier p = glm::defaultp>
 		operator glm::vec<tmpDim, T, p>() const {
 			glm::vec<tmpDim, T, p> res;
 			for (int64_t i = 0; i < dims; ++i) {
@@ -88,9 +86,7 @@ namespace librapid {
 		 * Functions take a single index and return a scalar value
 		 */
 
-		const DTYPE &operator[](int64_t index) const {
-			return m_components[index];
-		}
+		const DTYPE &operator[](int64_t index) const { return m_components[index]; }
 
 		DTYPE &operator[](int64_t index) { return m_components[index]; }
 
@@ -105,9 +101,7 @@ namespace librapid {
 			// Quick return to avoid excess checks
 			if (dims == tmpDims) return true;
 
-			for (int64_t i = MIN_DIM_CLAMP(dims, tmpDims);
-				 i < MAX_DIM_CLAMP(dims, tmpDims);
-				 ++i) {
+			for (int64_t i = MIN_DIM_CLAMP(dims, tmpDims); i < MAX_DIM_CLAMP(dims, tmpDims); ++i) {
 				if (i < dims && m_components[i]) return false;
 				if (i < tmpDims && other[i]) return false;
 			}
@@ -129,45 +123,37 @@ namespace librapid {
 		 * Vectors must have same dimensions. To cast, use Vec.as<TYPE, DIMS>()
 		 */
 		template<typename T, int64_t tmpDims>
-		Vec<Common<T>, MAX_DIM_CLAMP(dims, tmpDims)>
-		operator+(const Vec<T, tmpDims> &other) const {
+		Vec<Common<T>, MAX_DIM_CLAMP(dims, tmpDims)> operator+(const Vec<T, tmpDims> &other) const {
 			Vec<Common<T>, MAX_DIM_CLAMP(dims, tmpDims)> res;
 			for (int64_t i = 0; i < (MAX_DIM_CLAMP(dims, tmpDims)); ++i) {
-				res[i] = ((i < dims) ? m_components[i] : 0) +
-						 ((i < tmpDims) ? other[i] : 0);
+				res[i] = ((i < dims) ? m_components[i] : 0) + ((i < tmpDims) ? other[i] : 0);
 			}
 			return res;
 		}
 
 		template<typename T, int64_t tmpDims>
-		Vec<Common<T>, MAX_DIM_CLAMP(dims, tmpDims)>
-		operator-(const Vec<T, tmpDims> &other) const {
+		Vec<Common<T>, MAX_DIM_CLAMP(dims, tmpDims)> operator-(const Vec<T, tmpDims> &other) const {
 			Vec<Common<T>, MAX_DIM_CLAMP(dims, tmpDims)> res;
 			for (int64_t i = 0; i < (MAX_DIM_CLAMP(dims, tmpDims)); ++i) {
-				res[i] = ((i < dims) ? m_components[i] : 0) -
-						 ((i < tmpDims) ? other[i] : 0);
+				res[i] = ((i < dims) ? m_components[i] : 0) - ((i < tmpDims) ? other[i] : 0);
 			}
 			return res;
 		}
 
 		template<typename T, int64_t tmpDims>
-		Vec<Common<T>, MAX_DIM_CLAMP(dims, tmpDims)>
-		operator*(const Vec<T, tmpDims> &other) const {
+		Vec<Common<T>, MAX_DIM_CLAMP(dims, tmpDims)> operator*(const Vec<T, tmpDims> &other) const {
 			Vec<Common<T>, MAX_DIM_CLAMP(dims, tmpDims)> res;
 			for (int64_t i = 0; i < (MAX_DIM_CLAMP(dims, tmpDims)); ++i) {
-				res[i] = ((i < dims) ? m_components[i] : 0) *
-						 ((i < tmpDims) ? other[i] : 0);
+				res[i] = ((i < dims) ? m_components[i] : 0) * ((i < tmpDims) ? other[i] : 0);
 			}
 			return res;
 		}
 
 		template<typename T, int64_t tmpDims>
-		Vec<Common<T>, MAX_DIM_CLAMP(dims, tmpDims)>
-		operator/(const Vec<T, tmpDims> &other) const {
+		Vec<Common<T>, MAX_DIM_CLAMP(dims, tmpDims)> operator/(const Vec<T, tmpDims> &other) const {
 			Vec<Common<T>, MAX_DIM_CLAMP(dims, tmpDims)> res;
 			for (int64_t i = 0; i < (MAX_DIM_CLAMP(dims, tmpDims)); ++i) {
-				res[i] = ((i < dims) ? m_components[i] : 0) /
-						 ((i < tmpDims) ? other[i] : 0);
+				res[i] = ((i < dims) ? m_components[i] : 0) / ((i < tmpDims) ? other[i] : 0);
 			}
 			return res;
 		}
@@ -179,43 +165,31 @@ namespace librapid {
 		 * common type) containing the result of the element-wise operation.
 		 */
 
-		template<typename T, typename std::enable_if<std::is_scalar<T>::value,
-													 int>::type = 0>
+		template<typename T, typename std::enable_if<std::is_scalar<T>::value, int>::type = 0>
 		Vec<Common<T>, dims> operator+(const T &other) const {
 			Vec<Common<T>, dims> res;
-			for (int64_t i = 0; i < dims; ++i) {
-				res[i] = m_components[i] + other;
-			}
+			for (int64_t i = 0; i < dims; ++i) { res[i] = m_components[i] + other; }
 			return res;
 		}
 
-		template<typename T, typename std::enable_if<std::is_scalar<T>::value,
-													 int>::type = 0>
+		template<typename T, typename std::enable_if<std::is_scalar<T>::value, int>::type = 0>
 		Vec<Common<T>, dims> operator-(const T &other) const {
 			Vec<Common<T>, dims> res;
-			for (int64_t i = 0; i < dims; ++i) {
-				res[i] = m_components[i] - other;
-			}
+			for (int64_t i = 0; i < dims; ++i) { res[i] = m_components[i] - other; }
 			return res;
 		}
 
-		template<typename T, typename std::enable_if<std::is_scalar<T>::value,
-													 int>::type = 0>
+		template<typename T, typename std::enable_if<std::is_scalar<T>::value, int>::type = 0>
 		Vec<Common<T>, dims> operator*(const T &other) const {
 			Vec<Common<T>, dims> res;
-			for (int64_t i = 0; i < dims; ++i) {
-				res[i] = m_components[i] * other;
-			}
+			for (int64_t i = 0; i < dims; ++i) { res[i] = m_components[i] * other; }
 			return res;
 		}
 
-		template<typename T, typename std::enable_if<std::is_scalar<T>::value,
-													 int>::type = 0>
+		template<typename T, typename std::enable_if<std::is_scalar<T>::value, int>::type = 0>
 		Vec<Common<T>, dims> operator/(const T &other) const {
 			Vec<Common<T>, dims> res;
-			for (int64_t i = 0; i < dims; ++i) {
-				res[i] = m_components[i] / other;
-			}
+			for (int64_t i = 0; i < dims; ++i) { res[i] = m_components[i] / other; }
 			return res;
 		}
 
@@ -280,7 +254,7 @@ namespace librapid {
 		 */
 		DTYPE mag2() const {
 			DTYPE res = 0;
-			for (const auto &val : m_components) { res += val * val; }
+			for (int64_t i = 0; i < dims; ++i) { res += m_components[i] * m_components[i]; }
 			return res;
 		}
 
@@ -292,8 +266,7 @@ namespace librapid {
 		DTYPE invMag() const { return DTYPE(1) / sqrt(mag2()); }
 
 		template<typename T, int64_t tmpDims>
-		typename std::common_type<DTYPE, T>::type
-		dist2(const Vec<T, tmpDims> &other) const {
+		typename std::common_type<DTYPE, T>::type dist2(const Vec<T, tmpDims> &other) const {
 			using RET	= typename std::common_type<DTYPE, T>::type;
 			RET squared = 0;
 			int64_t i	= 0;
@@ -301,8 +274,7 @@ namespace librapid {
 			// Compute the squares of the differences for the matching
 			// components
 			for (; i < MIN_DIM_CLAMP(dims, tmpDims); ++i) {
-				squared +=
-				  (m_components[i] - other[i]) * (m_components[i] - other[i]);
+				squared += (m_components[i] - other[i]) * (m_components[i] - other[i]);
 			}
 
 			// Compute the squares of the values for the remaining values.
@@ -319,8 +291,7 @@ namespace librapid {
 		}
 
 		template<typename T, int64_t tmpDims>
-		typename std::common_type<DTYPE, T>::type
-		dist(const Vec<T, tmpDims> &other) const {
+		typename std::common_type<DTYPE, T>::type dist(const Vec<T, tmpDims> &other) const {
 			return sqrt(dist2(other));
 		}
 
@@ -331,9 +302,7 @@ namespace librapid {
 		template<typename T>
 		Common<T> dot(const Vec<T, dims> &other) const {
 			Common<T> res = 0;
-			for (int64_t i = 0; i < dims; ++i) {
-				res += m_components[i] * other[i];
-			}
+			for (int64_t i = 0; i < dims; ++i) { res += m_components[i] * other[i]; }
 			return res;
 		}
 
@@ -426,8 +395,7 @@ namespace librapid {
 		[[nodiscard]] std::string str() const {
 			std::string res = "(";
 			for (int64_t i = 0; i < dims; ++i) {
-				res += std::to_string(m_components[i]) +
-					   (i == dims - 1 ? ")" : ", ");
+				res += std::to_string(m_components[i]) + (i == dims - 1 ? ")" : ", ");
 			}
 			return res;
 		}
@@ -453,7 +421,7 @@ namespace librapid {
 		DTYPE &z = m_components[2];
 		DTYPE &w = m_components[3];
 
-	  private:
+	private:
 		DTYPE m_components[dims < 4 ? 4 : dims];
 	};
 
@@ -466,8 +434,8 @@ namespace librapid {
 
 	template<typename T, typename DTYPE, int64_t dims,
 			 typename std::enable_if<std::is_scalar<T>::value, int>::type = 0>
-	Vec<typename std::common_type<T, DTYPE>::type, dims>
-	operator+(const T &value, const Vec<DTYPE, dims> &vec) {
+	Vec<typename std::common_type<T, DTYPE>::type, dims> operator+(const T &value,
+																   const Vec<DTYPE, dims> &vec) {
 		Vec<typename std::common_type<T, DTYPE>::type, dims> res;
 		for (int64_t i = 0; i < dims; ++i) { res[i] = value + vec[i]; }
 		return res;
@@ -475,8 +443,8 @@ namespace librapid {
 
 	template<typename T, typename DTYPE, int64_t dims,
 			 typename std::enable_if<std::is_scalar<T>::value, int>::type = 0>
-	Vec<typename std::common_type<T, DTYPE>::type, dims>
-	operator-(const T &value, const Vec<DTYPE, dims> &vec) {
+	Vec<typename std::common_type<T, DTYPE>::type, dims> operator-(const T &value,
+																   const Vec<DTYPE, dims> &vec) {
 		Vec<typename std::common_type<T, DTYPE>::type, dims> res;
 		for (int64_t i = 0; i < dims; ++i) { res[i] = value - vec[i]; }
 		return res;
@@ -484,8 +452,8 @@ namespace librapid {
 
 	template<typename T, typename DTYPE, int64_t dims,
 			 typename std::enable_if<std::is_scalar<T>::value, int>::type = 0>
-	Vec<typename std::common_type<T, DTYPE>::type, dims>
-	operator*(const T &value, const Vec<DTYPE, dims> &vec) {
+	Vec<typename std::common_type<T, DTYPE>::type, dims> operator*(const T &value,
+																   const Vec<DTYPE, dims> &vec) {
 		Vec<typename std::common_type<T, DTYPE>::type, dims> res;
 		for (int64_t i = 0; i < dims; ++i) { res[i] = value * vec[i]; }
 		return res;
@@ -493,8 +461,8 @@ namespace librapid {
 
 	template<typename T, typename DTYPE, int64_t dims,
 			 typename std::enable_if<std::is_scalar<T>::value, int>::type = 0>
-	Vec<typename std::common_type<T, DTYPE>::type, dims>
-	operator/(const T &value, const Vec<DTYPE, dims> &vec) {
+	Vec<typename std::common_type<T, DTYPE>::type, dims> operator/(const T &value,
+																   const Vec<DTYPE, dims> &vec) {
 		Vec<typename std::common_type<T, DTYPE>::type, dims> res;
 		for (int64_t i = 0; i < dims; ++i) { res[i] = value / vec[i]; }
 		return res;
@@ -510,15 +478,21 @@ namespace librapid {
 		template<typename T>
 		using Common = typename std::common_type<DTYPE, T>::type;
 
-	  public:
+	public:
 		Vec() = default;
-		;
 
 		template<typename X = DTYPE, typename Y = DTYPE, typename Z = DTYPE>
-		Vec(X x, Y y = 0, Z z = 0) : x(x), y(y), z(z) {}
+		explicit Vec(X x, Y y = 0, Z z = 0) : x(x), y(y), z(z) {}
+
+		template<typename T>
+		Vec(const std::initializer_list<T> &vals) {
+			LR_ASSERT(vals.size() <= 3, "Parameters cannot exceed vector dimensions");
+			int64_t ind = 0;
+			for (const auto &val : vals) { operator[](ind++) = val; }
+		}
 
 		template<typename T, int64_t d>
-		Vec(const Vec<T, d> &other) {
+		explicit Vec(const Vec<T, d> &other) {
 			x = other.x;
 			y = other.y;
 			z = other.z;
@@ -557,9 +531,7 @@ namespace librapid {
 		template<typename T, int tmpDim, glm::qualifier p = glm::defaultp>
 		operator glm::vec<tmpDim, T, p>() const {
 			glm::vec<tmpDim, T, p> res;
-			for (int64_t i = 0; i < tmpDim; ++i) {
-				res[i] = (i < 3) ? ((&x)[i]) : (T(0));
-			}
+			for (int64_t i = 0; i < tmpDim; ++i) { res[i] = (i < 3) ? ((&x)[i]) : (T(0)); }
 			return res;
 		}
 
@@ -577,8 +549,7 @@ namespace librapid {
 		template<typename T, int64_t tmpDims>
 		bool operator==(const Vec<T, tmpDims> &other) const {
 			if (tmpDims <= 3) {
-				return x == other.x && y == other.y && z == other.z &&
-					   w == other.w;
+				return x == other.x && y == other.y && z == other.z && w == other.w;
 			}
 
 			for (int64_t i = 3; i < tmpDims; ++i) {
@@ -623,45 +594,37 @@ namespace librapid {
 		}
 
 		template<typename T, int64_t tmpDims>
-		Vec<Common<T>, MAX_DIM_CLAMP(3, tmpDims)>
-		operator+(const Vec<T, tmpDims> &other) const {
+		Vec<Common<T>, MAX_DIM_CLAMP(3, tmpDims)> operator+(const Vec<T, tmpDims> &other) const {
 			Vec<Common<T>, MAX_DIM_CLAMP(3, tmpDims)> res;
 			for (int64_t i = 0; i < (MAX_DIM_CLAMP(3, tmpDims)); ++i) {
-				res[i] =
-				  ((i < 3) ? (&x)[i] : 0) + ((i < tmpDims) ? other[i] : 0);
+				res[i] = ((i < 3) ? (&x)[i] : 0) + ((i < tmpDims) ? other[i] : 0);
 			}
 			return res;
 		}
 
 		template<typename T, int64_t tmpDims>
-		Vec<Common<T>, MAX_DIM_CLAMP(3, tmpDims)>
-		operator-(const Vec<T, tmpDims> &other) const {
+		Vec<Common<T>, MAX_DIM_CLAMP(3, tmpDims)> operator-(const Vec<T, tmpDims> &other) const {
 			Vec<Common<T>, MAX_DIM_CLAMP(3, tmpDims)> res;
 			for (int64_t i = 0; i < (MAX_DIM_CLAMP(3, tmpDims)); ++i) {
-				res[i] =
-				  ((i < 3) ? (&x)[i] : 0) - ((i < tmpDims) ? other[i] : 0);
+				res[i] = ((i < 3) ? (&x)[i] : 0) - ((i < tmpDims) ? other[i] : 0);
 			}
 			return res;
 		}
 
 		template<typename T, int64_t tmpDims>
-		Vec<Common<T>, MAX_DIM_CLAMP(3, tmpDims)>
-		operator*(const Vec<T, tmpDims> &other) const {
+		Vec<Common<T>, MAX_DIM_CLAMP(3, tmpDims)> operator*(const Vec<T, tmpDims> &other) const {
 			Vec<Common<T>, MAX_DIM_CLAMP(3, tmpDims)> res;
 			for (int64_t i = 0; i < (MAX_DIM_CLAMP(3, tmpDims)); ++i) {
-				res[i] =
-				  ((i < 3) ? (&x)[i] : 0) * ((i < tmpDims) ? other[i] : 0);
+				res[i] = ((i < 3) ? (&x)[i] : 0) * ((i < tmpDims) ? other[i] : 0);
 			}
 			return res;
 		}
 
 		template<typename T, int64_t tmpDims>
-		Vec<Common<T>, MAX_DIM_CLAMP(3, tmpDims)>
-		operator/(const Vec<T, tmpDims> &other) const {
+		Vec<Common<T>, MAX_DIM_CLAMP(3, tmpDims)> operator/(const Vec<T, tmpDims> &other) const {
 			Vec<Common<T>, MAX_DIM_CLAMP(3, tmpDims)> res;
 			for (int64_t i = 0; i < (MAX_DIM_CLAMP(3, tmpDims)); ++i) {
-				res[i] =
-				  ((i < 3) ? (&x)[i] : 0) / ((i < tmpDims) ? other[i] : 0);
+				res[i] = ((i < 3) ? (&x)[i] : 0) / ((i < tmpDims) ? other[i] : 0);
 			}
 			return res;
 		}
@@ -774,25 +737,21 @@ namespace librapid {
 		}
 
 		template<typename T, int64_t tmpDims>
-		typename std::common_type<DTYPE, T>::type
-		dist2(const Vec<T, tmpDims> &other) const {
+		typename std::common_type<DTYPE, T>::type dist2(const Vec<T, tmpDims> &other) const {
 			// Specific case for a 2D vector
 			if constexpr (tmpDims == 2) {
-				return ((x - other.x) * (x - other.x)) +
-					   ((y - other.y) * (y - other.y)) + (z * z);
+				return ((x - other.x) * (x - other.x)) + ((y - other.y) * (y - other.y)) + (z * z);
 			}
 
 			// Specific case for a 3D vector
 			if constexpr (tmpDims == 3) {
-				return ((x - other.x) * (x - other.x)) +
-					   ((y - other.y) * (y - other.y)) +
+				return ((x - other.x) * (x - other.x)) + ((y - other.y) * (y - other.y)) +
 					   ((z - other.z) * (z - other.z));
 			}
 
 			// Specific case for a 4D vector
 			if constexpr (tmpDims == 4) {
-				return ((x - other.x) * (x - other.x)) +
-					   ((y - other.y) * (y - other.y)) +
+				return ((x - other.x) * (x - other.x)) + ((y - other.y) * (y - other.y)) +
 					   ((z - other.z) * (z - other.z)) + (other.w * other.w);
 			}
 
@@ -819,8 +778,7 @@ namespace librapid {
 		}
 
 		template<typename T, int64_t tmpDims>
-		typename std::common_type<DTYPE, T>::type
-		dist(const Vec<T, tmpDims> &other) const {
+		typename std::common_type<DTYPE, T>::type dist(const Vec<T, tmpDims> &other) const {
 			return sqrt(dist2(other));
 		}
 
@@ -838,9 +796,8 @@ namespace librapid {
 		 */
 		template<typename T>
 		Vec<Common<T>, 3> cross(const Vec<T, 3> &other) const {
-			return Vec<Common<T>, 3>(y * other.z - z * other.y,
-									 z * other.x - x * other.z,
-									 x * other.y - y * other.x);
+			return Vec<Common<T>, 3>(
+			  y * other.z - z * other.y, z * other.x - x * other.z, x * other.y - y * other.x);
 		}
 
 		// Swizzle Operations
@@ -910,8 +867,8 @@ namespace librapid {
 		inline Vec<DTYPE, 4> wzyx() const { return {w, z, y, x}; }
 
 		[[nodiscard]] std::string str() const {
-			return std::string("(") + std::to_string(x) + ", " +
-				   std::to_string(y) + ", " + std::to_string(z) + ")";
+			return std::string("(") + std::to_string(x) + ", " + std::to_string(y) + ", " +
+				   std::to_string(z) + ")";
 		}
 
 		void setX(DTYPE val) { x = val; }
@@ -945,32 +902,32 @@ namespace librapid {
 
 	template<typename T, typename DTYPE,
 			 typename std::enable_if<std::is_scalar<T>::value, int>::type = 0>
-	Vec<typename std::common_type<T, DTYPE>::type, 3>
-	operator+(const T &value, const Vec<DTYPE, 3> &vec) {
+	Vec<typename std::common_type<T, DTYPE>::type, 3> operator+(const T &value,
+																const Vec<DTYPE, 3> &vec) {
 		return Vec<typename std::common_type<T, DTYPE>::type, 3>(
 		  value + vec.x, value + vec.y, value + vec.z);
 	}
 
 	template<typename T, typename DTYPE,
 			 typename std::enable_if<std::is_scalar<T>::value, int>::type = 0>
-	Vec<typename std::common_type<T, DTYPE>::type, 3>
-	operator-(const T &value, const Vec<DTYPE, 3> &vec) {
+	Vec<typename std::common_type<T, DTYPE>::type, 3> operator-(const T &value,
+																const Vec<DTYPE, 3> &vec) {
 		return Vec<typename std::common_type<T, DTYPE>::type, 3>(
 		  value - vec.x, value - vec.y, value - vec.z);
 	}
 
 	template<typename T, typename DTYPE,
 			 typename std::enable_if<std::is_scalar<T>::value, int>::type = 0>
-	Vec<typename std::common_type<T, DTYPE>::type, 3>
-	operator*(const T &value, const Vec<DTYPE, 3> &vec) {
+	Vec<typename std::common_type<T, DTYPE>::type, 3> operator*(const T &value,
+																const Vec<DTYPE, 3> &vec) {
 		return Vec<typename std::common_type<T, DTYPE>::type, 3>(
 		  value * vec.x, value * vec.y, value * vec.z);
 	}
 
 	template<typename T, typename DTYPE,
 			 typename std::enable_if<std::is_scalar<T>::value, int>::type = 0>
-	Vec<typename std::common_type<T, DTYPE>::type, 3>
-	operator/(const T &value, const Vec<DTYPE, 3> &vec) {
+	Vec<typename std::common_type<T, DTYPE>::type, 3> operator/(const T &value,
+																const Vec<DTYPE, 3> &vec) {
 		return Vec<typename std::common_type<T, DTYPE>::type, 3>(
 		  value / vec.x, value / vec.y, value / vec.z);
 	}
