@@ -8,7 +8,13 @@ typeMap = {
 	"ArrayF64" : ("double", "float64", "f64"),
 	"ArrayI16" : ("short", "int16", "i16"),
 	"ArrayI32" : ("int", "long", "int32", "i32"),
-	"ArrayI64" : ("long long", "int64", "i64")
+	"ArrayI64" : ("long long", "int64", "i64"),
+	"ArrayMPZ" : ("bigint", "mpz", "mpz_t", "mpz_class", "mpir_int"),
+	"ArrayMPQ" : ("bigrational", "mpq", "mpq_t", "mpq_class", "mpir_rational"),
+	"ArrayMPFR" : ("bigfloat", "mpfr", "mpreal", "mpfr_float"),
+	"ArrayCF32" : ("complex float", "cfloat", "cf32", "c32"),
+	"ArrayCF64" : ("compled double", "cdouble", "cf64", "c64"),
+	"ArrayCMPFR" : ("complex multiprecision", "complex multiprec", "cmpfr", "cmpf", "cmp")
 }
 
 deviceMap = {
