@@ -1,5 +1,9 @@
 #include <librapid/cuda/cudaCodeLoader.hpp>
 
+#if defined(HAVE_CONFIG_H)
+#	error "WHY IS C++ SO AWFUL"
+#endif
+
 namespace librapid {
 	void loadCustomCudaHeader(const std::string &fileName, const std::string &searchDir,
 							  std::vector<std::string> &res, std::vector<std::string> &args) {
